==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QAccessibleApplication_shell.h <==
#ifndef QACCESSIBLEAPPLICATION_SHELL_H
#define QACCESSIBLEAPPLICATION_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qaccessibleobject.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qobject.h>
#include <QtCore/qrect.h>
#include <QtGui/qaccessible.h>
#include <QtGui/qaccessible_base.h>
#include <QtGui/qcolor.h>
#include <QtGui/qwindow.h>
#include <QtJambi/RegistryAPI>


class QAccessibleApplication_shell : public QAccessibleApplication, public QtJambiShellInterface
{
public:
    QAccessibleApplication_shell();
    ~QAccessibleApplication_shell() override;

    QColor backgroundColor() const override;
    QAccessibleInterface* child(int index0) const override;
    QAccessibleInterface* childAt(int x0, int y1) const override;
    int childCount() const override;
    QAccessibleInterface* focusChild() const override;
    QColor foregroundColor() const override;
    int indexOfChild(const QAccessibleInterface* arg__1) const override;
    bool isValid() const override;
    QObject* object() const override;
    QAccessibleInterface* parent() const override;
    QRect rect() const override;
    QList<QPair<QAccessibleInterface*, QAccessible::Relation> > relations(QAccessible::Relation match0) const override;
    QAccessible::Role role() const override;
    void setText(QAccessible::Text t0, const QString& text1) override;
    QAccessible::State state() const override;
    QString text(QAccessible::Text t0) const override;
    QWindow* window() const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAccessibleApplication_access : public QAccessibleApplication
{
    jobject __qt_child_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    jint __qt_childCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_focusChild(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_indexOfChild_const_QAccessibleInterface_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    jobject __qt_parent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_role(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_state(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_text_QAccessible_Text_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint t0) const;
    jobject __qt_window(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QACCESSIBLEAPPLICATION_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QAccessibleApplication_shell.h <==
#ifndef QACCESSIBLEAPPLICATION_SHELL_H
#define QACCESSIBLEAPPLICATION_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qaccessibleobject.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qobject.h>
#include <QtCore/qrect.h>
#include <QtGui/qaccessible.h>
#include <QtGui/qaccessible_base.h>
#include <QtGui/qcolor.h>
#include <QtGui/qwindow.h>
#include <QtJambi/RegistryAPI>


class QAccessibleApplication_shell : public QAccessibleApplication, public QtJambiShellInterface
{
public:
    QAccessibleApplication_shell();
    ~QAccessibleApplication_shell() override;

    QColor backgroundColor() const override;
    QAccessibleInterface* child(int index0) const override;
    QAccessibleInterface* childAt(int x0, int y1) const override;
    int childCount() const override;
    QAccessibleInterface* focusChild() const override;
    QColor foregroundColor() const override;
    int indexOfChild(const QAccessibleInterface* arg__1) const override;
    bool isValid() const override;
    QObject* object() const override;
    QAccessibleInterface* parent() const override;
    QRect rect() const override;
    QList<QPair<QAccessibleInterface*, QAccessible::Relation> > relations(QAccessible::Relation match0) const override;
    QAccessible::Role role() const override;
    void setText(QAccessible::Text t0, const QString& text1) override;
    QAccessible::State state() const override;
    QString text(QAccessible::Text t0) const override;
    QWindow* window() const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAccessibleApplication_access : public QAccessibleApplication
{
    jobject __qt_child_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    jint __qt_childCount_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_focusChild_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_indexOfChild_const_QAccessibleInterface_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    jobject __qt_parent_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_role_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_state_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_text_QAccessible_Text_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint t0) const;
    jobject __qt_window_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QACCESSIBLEAPPLICATION_SHELL_H
